import { 
  scaleLinear,
	scaleBand,
  axisLeft,
  axisBottom,
	max
} from 'd3';


export const barChars = (data, selection, props) => {
  
  const {
  	height,
    width,
    selectedBar,
    onHover
  } = props;
  
  const margin = { left: 90, right: 20, top: 20, bottom: 30 }
  const yValue = d => d.time;
  const xValue = d => d.dif;
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.right - margin.left;
  
	const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.1);

  const g = selection.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})` );

  const yAxis = axisLeft(yScale);
  const xAxis = axisBottom(xScale);
  
  g.append('g').call(yAxis);
  g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  g.selectAll('rect')
  	.data(data).enter().append('rect')
      .attr('y', d => yScale(yValue(d)))
      .attr('width', d => xScale(xValue(d)))
      .attr('height', yScale.bandwidth())
  		.merge(g.selectAll('rect').data(data))
    	.on('mouseover', d => onHover(d.time))
  		.on('mouseout', d => onHover(null))
    	.attr('stroke', d => 
            d.time === selectedBar 
            ? 'black' 
            : 'none')
  		.attr('stroke-width', 1);

}
